==> haskell-asn1-encoding-0.9.5-99-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-encoding.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-encoding
version: 0.9.5
id: asn1-encoding-0.9.5-GnbcxVcyGEJ8Q4QPyFmhzh
key: asn1-encoding-0.9.5-GnbcxVcyGEJ8Q4QPyFmhzh
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1
synopsis: ASN1 data reader and writer in RAW, BER and DER forms
description:
    ASN1 data reader and writer in raw form with supports for high level forms of ASN1 (BER, and DER).
category: Data
abi: f6db0771c9e92547ef0acd648d21f0c6
exposed: True
exposed-modules:
    Data.ASN1.BinaryEncoding Data.ASN1.BinaryEncoding.Raw
    Data.ASN1.Encoding Data.ASN1.Error Data.ASN1.Object
    Data.ASN1.Stream
hidden-modules: Data.ASN1.Prim Data.ASN1.BinaryEncoding.Parse
                Data.ASN1.BinaryEncoding.Writer Data.ASN1.Internal
                Data.ASN1.Serialize Data.ASN1.Get
import-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-encoding-0.9.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-encoding-0.9.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/asn1-encoding-0.9.5
hs-libraries: HSasn1-encoding-0.9.5-GnbcxVcyGEJ8Q4QPyFmhzh
depends:
    asn1-types-0.3.3-4Uk1PObX3MW4QyDGQKlaYD base-4.12.0.0
    bytestring-0.10.8.2 hourglass-0.2.12-IV73mzafuus4ZSHhtC19I2
haddock-interfaces: /usr/share/doc/haskell-asn1-encoding/html/asn1-encoding.haddock
haddock-html: /usr/share/doc/haskell-asn1-encoding/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-encoding-0.9.5-101-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-encoding.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-encoding
version: 0.9.5
id: asn1-encoding-0.9.5-KleZSJPrHkB1mec3sCGM7s
key: asn1-encoding-0.9.5-KleZSJPrHkB1mec3sCGM7s
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1
synopsis: ASN1 data reader and writer in RAW, BER and DER forms
description:
    ASN1 data reader and writer in raw form with supports for high level forms of ASN1 (BER, and DER).
category: Data
abi: b74d4c959a47b5b17f2c0a9f9e648fc9
exposed: True
exposed-modules:
    Data.ASN1.BinaryEncoding Data.ASN1.BinaryEncoding.Raw
    Data.ASN1.Encoding Data.ASN1.Error Data.ASN1.Object
    Data.ASN1.Stream
hidden-modules: Data.ASN1.Prim Data.ASN1.BinaryEncoding.Parse
                Data.ASN1.BinaryEncoding.Writer Data.ASN1.Internal
                Data.ASN1.Serialize Data.ASN1.Get
import-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-encoding-0.9.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/asn1-encoding-0.9.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/asn1-encoding-0.9.5
hs-libraries: HSasn1-encoding-0.9.5-KleZSJPrHkB1mec3sCGM7s
depends:
    asn1-types-0.3.3-3LsLfgBZo6dINYctxdqtMH base-4.12.0.0
    bytestring-0.10.8.2 hourglass-0.2.12-FpLbTYFHrqgLFdm1LIXYUv
haddock-interfaces: /usr/share/doc/haskell-asn1-encoding/html/asn1-encoding.haddock
haddock-html: /usr/share/doc/haskell-asn1-encoding/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
